.. image:: https://raw.githubusercontent.com/pyQode/pyqode.core/develop/doc/source/_static/pyqode-banner.png


About
-----
.. image:: http://img.shields.io/pypi/v/pyqode.cobol.png
    :target: https://pypi.python.org/pypi/pyqode.cobol/
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/pyQode/pyqode.cobol.svg?branch=master
    :target: https://travis-ci.org/pyQode/pyqode.cobol
    :alt: Travis-CI build status

.. image:: https://coveralls.io/repos/pyQode/pyqode.cobol/badge.png?branch=master
    :target: https://coveralls.io/r/pyQode/pyqode.cobol?branch=master
    :alt: Coverage Status

*pyqode.cobol* adds **COBOL** support to `pyqode.core`_ (code completion,
code folding,...).


Features:
---------

  * cobol code completion provider based on the cobol keywords and the defined
    names of the current document (pic fields, paragraphes)
  * code folding mode
  * auto indent mode (after struct, paragraph or inside procedures)
  * native (fast) syntax highlighter with pygments themes support.
  * document outline widget

License
-------

pyqode.cobol is licensed under the GPL v3.


Requirements
------------

pyqode.cobol depends on the following libraries:

 - pyqode.core


Installation
------------

::

    $ pip3 install pyqode.cobol


Resources
---------

-  `Downloads`_
-  `Source repository`_


.. _Downloads: https://github.com/pyQode/pyqode.python/releases
.. _Source repository: https://github.com/pyQode/pyqode.python/
.. _pyqode.core: https://github.com/pyQode/pyqode.core

